#!/bin/sh
#

WEBOTX_HOME=/opt/WebOTX
USER=admin
PASSWORD=adminadmin
PORT=6212
LANG=en_US.UTF-8
UBUNTUFILE=/etc/os-release
TURBOFILE=/etc/turbolinux-release

OS=`uname -s`
if [ ${OS} = 'Linux' ]; then
    keyword=
    if [ -f ${UBUNTUFILE} ]; then
        keyword=`cat ${UBUNTUFILE} | grep -i Ubuntu`
        if [ -n "${keyword}" ]; then
            OS="UbuOrTur"
        fi
    fi
    keyword=
    if [ -f ${TURBOFILE} ];then
        keyword=`cat ${TURBOFILE} | grep -i Turbolinux`
        if [ -n "${keyword}" ]; then
            OS="UbuOrTur"
        fi
    fi
fi

## define the commands
if [ ${OS} = 'Linux' ]; then
    DATE=`which --skip-alias date`
    CAT=`which --skip-alias cat`
    CUT=`which --skip-alias cut`
    PS=`which --skip-alias ps`
    SED=`which --skip-alias sed`
    GREP=`which --skip-alias grep`
    EXPR=`which --skip-alias expr`
    DIRNAME=`which --skip-alias dirname`
elif [ ${OS} = 'UbuOrTur' ]; then
    DATE=`which -a date`
    CAT=`which -a cat`
    CUT=`which -a cut | head -1`
    PS=`which -a ps`
    SED=`which -a sed`
    GREP=`which -a grep`
    EXPR=`which -a expr`
    DIRNAME=`which -a dirname`
fi

JRA_BIN=`dirname $0`
JRA_HOME=`cd ${JRA_BIN}; cd ..; pwd`

# default value
MONITOR_SH=${JRA_HOME}/bin/monitor.sh
CONF_DIRECTORY=${JRA_HOME}/conf
JVM_CONF=${CONF_DIRECTORY}/jvmsaver.conf
OTXADMIN=${WEBOTX_HOME}/bin/otxadmin
JVM_COUNT=10

# messages
msg_001="Can not find the jvm.n.conf by jvm.name."
msg_002="Can not get jvm.user.id, jvm.user.passwd, jvm.port from jvm.n.conf."
msg_003="Usage: webotx-restart.sh -N=JVM_NAME [-C=CHECK]"
msg_004="Failed to login to the domain."
msg_005="Failed to start domain."
msg_006="Failed to stop domain."
msg_007="Configure the correct WEBOTX_HOME."
msg_008="Configure the correct JVM_NAME."
msg_009="Domain is not running."


####
# parse_option
####
parse_option()
{
  OPTION_1=`echo $1 | ${CUT} -f 1 -d "="`
  OPTION_2=`echo $1 | ${CUT} -f 2 -d "="`
  case $OPTION_1
  in
    -N)
      JVM_PNAME=${OPTION_2} ;;
    -C)
      STALL_CHECK=${OPTION_2} ;;
    -D)
      USER_DIR=${OPTION_2} ;;
    -P)
      PORT=${OPTION_2} ;;
    -L)
      LOG_DIRECTORY=${OPTION_2} ;;
    -O)
      JVM_STDOUT=${OPTION_2} ;;
    -E)
      JVM_STDERR=${OPTION_2} ;;
    -G)
      GCLOG_DIR=${OPTION_2} ;;
    -I)
      USER=${OPTION_2} ;;
    -W)
      PASSWORD=${OPTION_2} ;;
    *)
      echo ${msg_003}
      return 1;;
    esac
  return 0
}

####
# get_val_by_key
####
get_val_by_key()
{
  KEY=$1
  CONF_FILE=$2
  VALUE=`${CAT} ${CONF_FILE} | ${SED} 's/ //g' | ${GREP} "^${KEY}="`
  if [ $? -ne 0 ] ; then
    return 1
  fi
  VALUE=${VALUE##*=}
  return 0
}

####
# get_conf_by_jvmname
####
get_conf_by_jvmname()
{
  INDEX=0
  while [ ${INDEX} -lt ${JVM_COUNT} ] ; do
    CONF_FILE=${CONF_DIRECTORY}/jvm.${INDEX}.conf
    if [ -f ${CONF_FILE} ] ; then
      get_val_by_key "jvm.name" ${CONF_FILE}
      if [[ $? -eq 0 && "${VALUE}X" = "${JVM_PNAME}X" ]] ; then
        break
      fi
    fi
    INDEX=`${EXPR} ${INDEX} + 1`
  done

  if [ ${INDEX} -eq ${JVM_COUNT} ] ; then
    echo ${msg_001}
    return 1
  fi
  return 0
}

####
# read_conf_file
####
read_conf_file()
{
  ${OTXADMIN} version | ${GREP} "WebOTX 7" 2>&1
  if [ $? -eq 0 ] ; then
    return 0
  fi

  get_val_by_key "jvm.user.id" ${CONF_FILE}
  if [ $? -eq 0 ] ; then
    USER=${VALUE}
  fi

  get_val_by_key "jvm.user.passwd" ${CONF_FILE}
  if [ $? -eq 0 ] ; then
    PASSWORD=${VALUE}
  fi

  get_val_by_key "jvm.port" ${CONF_FILE}
  if [ $? -eq 0 ] ; then
    PORT=${VALUE}
  fi
  return 0
}

####
#get_jvm_count
####
get_jvm_count()
{
  if [ ! -f ${JVM_CONF} ] ; then
    return 1
  fi
  get_val_by_key "jvm.count" ${JVM_CONF}
  if [ $? -ne 0 ] ; then
    return 1
  fi
  ${EXPR} "${VALUE}" : "^[0-9]*$" >/dev/null 2>&1
  if [ $? -ne 0 ] ; then
    return 1
  fi
  if [[ ${VALUE} -gt 25 || ${VALUE} -lt 1 ]] ; then
    return 1
  fi
  JVM_COUNT=${VALUE}
  return 0
}

####
# check the jvm whether it is stall or not
####
stall_check()
{
  #check the domain status
  if [ "${STATUS}" != "${JVM_PNAME} running" ] ; then
    echo ${msg_009}
    return 1
  fi

#  read_conf_file
  if [[ "${USER}X" = "X" || "${PASSWORD}X" = "X" || "${PORT}X" = "X" ]] ; then
    echo ${msg_002}
    return 1
  fi

  ${OTXADMIN} login --user ${USER} --password ${PASSWORD} --host localhost --port ${PORT} 2>&1
  if [ $? -ne 0 ] ; then
    echo ${msg_004}
    return 1
  fi
  return 0
}

####
# restart the domain
####
restart_domain()
{
  #check the domain status
  if [ "${STATUS}" != "${JVM_NAME} not running" ] ; then
    ${OTXADMIN} stop-domain ${JVM_PNAME}
    if [ $? -ne 0 ] ; then
      echo ${msg_006}
      return 1
    fi
  fi

  ${OTXADMIN} start-domain ${JVM_PNAME}
  if [ $? -ne 0 ] ; then
    echo ${msg_005}
    return 1
  fi
  return 0
}

###
# main
###
if [ $# -lt 1 ] ; then
 echo ${msg_003}
 exit 1
fi

#parse_option
while [ $# -gt 0 ]
do
  parse_option "$1"
  if [ $? -ne 0 ] ; then
    exit 1
  fi
  shift 1
done

if [ "${JVM_PNAME}" = "" ] ; then
  echo ${msg_003}
  exit 1
fi

#check the otxadmin
if [ ! -f ${OTXADMIN} ] ; then
  echo ${msg_007}
  exit 1
fi

#get the jvm.count
#get_jvm_count

#get the jvm.n.conf by jvm.name
#get_conf_by_jvmname
#if [ $? -ne 0 ] ; then
#  exit 1
#fi

#check the domain name
STATUS=`${OTXADMIN} list-domains | ${GREP} "^${JVM_PNAME} "`
if [ $? -ne 0 ] ; then
  echo ${msg_008}
  exit 1
fi

if [ "${STALL_CHECK}" = "CHECK" ] ; then
  stall_check
  RV=$?
else
  #${MONITOR_SH} stop ${INDEX}
  restart_domain
  RV=$?
  #${MONITOR_SH} start ${INDEX}
fi

exit ${RV}
